@@ -38,6 +38,18 @@ def _generate_time_serie(fromdate, todate, ndate_initializer, incr):
     yield cdate, todate
 
 
+def add_one_week(d):
+    return d + timedelta(days=7)
+
+
+def add_one_month(d):
+    try:
+        nextmonth = (d.replace(day=28) + timedelta(days=7)).replace(day=d.day)
+    except ValueError:  # assuming January 31 should return last day of February.
+        nextmonth = (d + timedelta(days=31)).replace(day=1) - timedelta(days=1)
+    return nextmonth
+
+
 def now(roundtominute=False):
     date = datetime.now()
     return to_local(date, roundtominute)
