@@ -56,7 +56,9 @@ class DataTypeId:
     dataquality = 'dataquality'
     datapoints = 'datapoints'
     mappingroadsdatapoints = 'mappingroadsdatapoints'
-    traveltimes = 'traveltimes'
+    zonestraveltime = 'zonestraveltime'
+
+    imputedprefixe = 'imputed'
 
 
 class NetworkObjId:
